@@ -163,7 +163,7 @@ z_py_zorp_stream_destroy(PyObject *o)
   ZorpStream *self = (ZorpStream *) o;
 
   z_stream_unref(self->stream);
-  PyMem_DEL(self);
+  PyObject_Del(self);
 }
 
 /**
