@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -40,7 +40,7 @@
 #include <zorp/authprovider.h>
 #include <zorp/misc.h>
 #include <zorp/policy.h>
-#include <zorp/proxy/base64.h>
+#include <zorp/proxy/code_base64.h>
 
 #include <ctype.h>
 #include <sys/socket.h>
@@ -190,7 +190,7 @@ http_config_set_defaults(HttpProxy *self)
   self->max_url_length = 4096;
   self->max_header_lines = 50;
   self->max_hostname_length = 256;
-  self->max_chunk_length = 262144;
+  self->max_chunk_length = 0;
   self->timeout_request = 10000;
   self->timeout = 300000;
   self->default_http_port = 80;
@@ -1141,11 +1141,12 @@ http_process_base64(gchar *dst, guint dstlen, gchar *src, guint srclen)
 {
   ZCode *auth_line;
   
-  auth_line = z_code_base64_new();
-
-  auth_line->decode_start((auth_line));
-
-  if (auth_line->decode(auth_line, src, srclen, dst, &dstlen) == FALSE)
+  auth_line = z_code_base64_decode_new(0, FALSE);
+  
+  z_code_transform(auth_line, src, srclen);
+  z_code_finish(auth_line);
+  dstlen = z_code_get_result(auth_line, dst, dstlen-1); 
+  if (z_code_get_errors(auth_line) != 0)
     {
       /* caller is logging */
       z_leave();
@@ -1154,8 +1155,7 @@ http_process_base64(gchar *dst, guint dstlen, gchar *src, guint srclen)
 
   dst[dstlen] = 0;
 
-  g_free(auth_line);
-
+  z_code_free(auth_line);
   return TRUE;
 }
 
@@ -1922,6 +1922,7 @@ http_connect_server(HttpProxy *self)
 {
   z_proxy_enter(self);
   if (!self->super.endpoints[EP_SERVER] ||
+      z_stream_broken(self->super.endpoints[EP_SERVER]) || 
       (!self->transparent_mode && 
         (strcasecmp(self->remote_server->str, self->connected_server->str) != 0 ||
          self->remote_port != self->connected_port)) ||
@@ -2076,7 +2077,10 @@ http_copy_request(HttpProxy *self)
            * GError here */
           
           if (self->reattempt_connection)
-            continue;
+            {
+              self->force_reconnect = TRUE;
+              continue;
+            }
             
           /* http_data_transfer already logs */
           z_proxy_leave(self);
